@@ -99,7 +99,7 @@ MHRM.group <- function(pars, constrain, Ls, Data, PrepList, list, random = list(
     }
     names(longpars) <- names(estpars)
     stagecycle <- 1L
-    converge <- 1L
+    converge <- TRUE
     noninvcount <- 0L
     estindex <- index[estpars]
     L <- Ls$L
@@ -294,7 +294,7 @@ MHRM.group <- function(pars, constrain, Ls, Data, PrepList, list, random = list(
             gthetatmp <- lapply(gtheta0, function(x, prodlist) prodterms(x, prodlist),
                               prodlist=prodlist)
         tmp <- .Call('computeDPars', pars, gthetatmp, OffTerm, length(longpars), TRUE,
-                     USE.FIXED)
+                     USE.FIXED, 0L)
         g <- tmp$grad; h <- tmp$hess
         if(length(list$SLOW.IND)){
             for(group in 1L:ngroups){
@@ -433,7 +433,7 @@ MHRM.group <- function(pars, constrain, Ls, Data, PrepList, list, random = list(
     if(cycles == NCYCLES + BURNIN + SEMCYCLES && !list$USEEM){
         if(list$message)
             message('MHRM terminated after ', NCYCLES, ' iterations.')
-        converge <- 0L
+        converge <- FALSE
     }
     if(list$USEEM) longpars <- list$startlongpars
     for(g in 1L:ngroups){
