@@ -42,8 +42,8 @@ fixef <- function(x){
     if(missing(x)) missingMsg('x')
     if(!(is(x, 'MixedClass') || is(x, 'SingleGroupClass')))
         stop('Only applicable to MixedClass and SingleGroupClass objects', call.=FALSE)
-    if(!length(x@lrPars))
+    if(!length(x@Model$lrPars))
         stop('No latent regression parameters were defined in the supplied model', call.=FALSE)
-    ret <- x@lrPars@X %*% x@lrPars@beta
+    ret <- x@Model$lrPars@X %*% x@Model$lrPars@beta
     ret
 }
