@@ -62,7 +62,7 @@
 #' par(ask=FALSE)
 #'
 #' # Using point estimates from the model
-#' Theta <- fscores(mod, full.scores=TRUE)
+#' Theta <- fscores(mod)
 #' IG0 <- itemGAM(dat[,1], Theta) #good item
 #' IG1 <- itemGAM(baditems[,1], Theta)
 #' IG2 <- itemGAM(baditems[,2], Theta)
@@ -96,7 +96,7 @@
 #' plot(ks, items = c(1,2,32))
 #'
 #' # splines approach
-#' Theta <- fscores(mod, full.scores=TRUE)
+#' Theta <- fscores(mod)
 #' IG <- itemGAM(SAT12[,32], Theta)
 #' plot(IG)
 #'
@@ -112,7 +112,7 @@
 #'
 #' ### multidimensional example by returning the GAM objects
 #' mod2 <- mirt(dat, 2)
-#' Theta <- fscores(mod2, full.scores=TRUE)
+#' Theta <- fscores(mod2)
 #' IG4 <- itemGAM(SAT12[,32], Theta, formula = resp ~ s(Theta1, k=10) + s(Theta2, k=10),
 #'    return.models=TRUE)
 #' names(IG4)
@@ -130,6 +130,7 @@ itemGAM <- function(item, Theta, formula = resp ~ s(Theta, k = 10), CI = .95,
     keep <- !is.na(item)
     mm <- model.matrix(~ 0 + factor(item))
     if(is.list(Theta)){
+        stopifnot(is.matrix(Theta[[1L]]))
         pvfit <- pvfit_se <- vector('list', length(Theta))
         fit <- vector('list', ncol(mm))
         for(j in 1L:ncol(mm)){
@@ -150,6 +151,7 @@ itemGAM <- function(item, Theta, formula = resp ~ s(Theta, k = 10), CI = .95,
         cat <- rep(paste0('cat_', 1:ncol(mm)), each=nrow(fit[[1L]]))
         ret <- cbind(do.call(rbind, fit), cat)
     } else {
+        stopifnot(is.matrix(Theta))
         nfact <- ncol(Theta)
         if(nfact > 1L && !return.models){
             return.models <- TRUE
