@@ -5,7 +5,7 @@
 #' @aliases testinfo
 #' @param x an estimated mirt object
 #' @param Theta a matrix of latent trait values
-#' @param degrees a vector of angles in degrees that are between 0 and 90 that jointly sum to 90.
+#' @param degrees a vector of angles in degrees that are between 0 and 90.
 #'   Only applicable when the input object is multidimensional
 #' @param group a number signifying which group the item should be extracted from (applies to
 #'   'MultipleGroupClass' objects only)
@@ -39,9 +39,8 @@
 testinfo <- function(x, Theta, degrees = NULL, group = NULL){
     if(missing(x)) missingMsg('x')
     if(missing(Theta)) missingMsg('Theta')
-    if(is(x, 'MultipleGroupClass'))
-        J <- length(x@pars[[1]]@pars) - 1
-    else J <- length(x@pars) - 1
+    if(!is.matrix(Theta)) Theta <- as.matrix(Theta)
+    J <- x@Data$nitems
     info <- 0
     for(i in 1L:J){
         item <- extract.item(x, i, group=group)
