@@ -31,7 +31,6 @@ draw.thetas <- function(theta0, pars, fulldata, itemloc, cand.t.var, prior.t.var
 {
     makedraws <- try({
         N <- nrow(fulldata)
-        J <- length(pars) - 1L
         unif <- runif(N)
         sigma <- if(ncol(theta0) == 1L) matrix(cand.t.var) else diag(rep(cand.t.var,ncol(theta0)))
         total_0 <- attr(theta0, 'log.lik_full')
@@ -43,9 +42,8 @@ draw.thetas <- function(theta0, pars, fulldata, itemloc, cand.t.var, prior.t.var
         itemtrace1 <- computeItemtrace(pars=pars, Theta=theta1, itemloc=itemloc,
                                        offterm=OffTerm, CUSTOM.IND=CUSTOM.IND)
         total_1 <- rowSums(fulldata * log(itemtrace1)) + log_den1
-        if(!is.null(prodlist))
-            theta1 <- theta1[ ,1L:(pars[[1L]]@nfact - pars[[1L]]@nfixedeffects -
-                                       length(prodlist)), drop=FALSE]
+        theta1 <- theta1[ ,1L:(pars[[1L]]@nfact - pars[[1L]]@nfixedeffects -
+                                   length(prodlist)), drop=FALSE]
         if(is.null(total_0)){ #for intial draw
             attr(theta1, 'log.lik_full') <- total_1
             return(theta1)
@@ -100,26 +98,26 @@ imputePars2 <- function(MGmod, shortpars, longpars, imputenums, pre.ev){
     while(TRUE){
         shift <- mirt_rmvnorm(1L, mean=shortpars, pre.ev=pre.ev)
         longpars[imputenums] <- shift[1L,]
-        constrain <- MGmod@constrain
+        constrain <- MGmod@Model$constrain
         if(length(constrain) > 0L)
             for(i in 1L:length(constrain))
                 longpars[constrain[[i]][-1L]] <- longpars[constrain[[i]][1L]]
-        pars <- list(MGmod@pars[[1L]]@pars, MGmod@pars[[2L]]@pars)
+        pars <- list(MGmod@ParObjects$pars[[1L]]@ParObjects$pars, MGmod@ParObjects$pars[[2L]]@ParObjects$pars)
         pars <- reloadPars(longpars=longpars, pars=pars, ngroups=2L, J=length(pars[[1L]])-1L)
-        if(any(MGmod@itemtype %in% c('graded', 'grsm'))){
-            pick <- c(MGmod@itemtype %in% c('graded', 'grsm'), FALSE)
+        if(any(MGmod@Model$itemtype %in% c('graded', 'grsm'))){
+            pick <- c(MGmod@Model$itemtype %in% c('graded', 'grsm'), FALSE)
             if(!all(sapply(pars[[1L]][pick], CheckIntercepts) &
                     sapply(pars[[2L]][pick], CheckIntercepts))) next
         }
         break
     }
-    MGmod@pars[[1L]]@pars <- pars[[1L]]
-    MGmod@pars[[2L]]@pars <- pars[[2L]]
+    MGmod@ParObjects$pars[[1L]]@ParObjects$pars <- pars[[1L]]
+    MGmod@ParObjects$pars[[2L]]@ParObjects$pars <- pars[[2L]]
     MGmod
 }
 
 # Rotation function
-Rotate <- function(F, rotate, Target = NULL, ...)
+Rotate <- function(F, rotate, Target = NULL, par.strip.text = NULL, par.settings = NULL, ...)
 {
     if(ncol(F) == 1L) rotF <- list()
     if(rotate == 'none') rotF <- list(loadings=F, Phi=diag(ncol(F)), orthogonal=TRUE)
@@ -177,22 +175,22 @@ Rotate <- function(F, rotate, Target = NULL, ...)
 gamma.cor <- function(x)
 {
 	concordant <- function(x){
-			mat.lr <- function(r, c){
+			mat.lr <- function(r, c, r.x, c.x){
 				lr <- x[(r.x > r) & (c.x > c)]
 				sum(lr)
 			}
 		r.x <- row(x)
 		c.x <- col(x)
-		sum(x * mapply(mat.lr, r = r.x, c = c.x))
+		sum(x * mapply(mat.lr, r = r.x, c = c.x, MoreArgs=list(r.x=r.x, c.x=c.x)))
 	}
 	discordant <- function(x){
-		mat.ll <- function(r, c){
+		mat.ll <- function(r, c, r.x, c.x){
 			ll <- x[(r.x > r) & (c.x < c)]
 			sum(ll)
 		}
 		r.x <- row(x)
 		c.x <- col(x)
-		sum(x * mapply(mat.ll, r = r.x, c = c.x))
+		sum(x * mapply(mat.ll, r = r.x, c = c.x, MoreArgs=list(r.x=r.x, c.x=c.x)))
 	}
 	c <- concordant(x)
 	d <- discordant(x)
@@ -204,7 +202,6 @@ gamma.cor <- function(x)
 cormod <- function(fulldata, K, guess, smooth = TRUE, use = 'pairwise.complete.obs')
 {
 	fulldata <- as.matrix(fulldata)
-	nitems <- ncol(fulldata)
 	cormat <- suppressWarnings(cor(fulldata, use=use))
     diag(cormat) <- 1
     cormat[is.na(cormat)] <- 0
@@ -346,7 +343,7 @@ bfactor2mod <- function(model, J){
     return(model)
 }
 
-updatePrior <- function(pars, Theta, Thetabetween, list, ngroups, nfact, J, N,
+updatePrior <- function(pars, Theta, Thetabetween, list, ngroups, nfact, J,
                         BFACTOR, sitems, cycles, rlist, prior, lrPars = list(), full=FALSE){
     Prior <- Priorbetween <- vector('list', ngroups)
     if(list$EH){
@@ -523,7 +520,6 @@ UpdateConstrain <- function(pars, constrain, invariance, nfact, nLambdas, J, ngr
                 constrain[[length(constrain) + 1L]] <- PrepList[[g]]$constrain[[i]]
     if('covariances' %in% invariance){ #Fix covariance accross groups (only makes sense with vars = 1)
         tmpmat <- matrix(NA, nfact, nfact)
-        low_tri <- lower.tri(tmpmat)
         tmp <- c()
         tmpmats <- tmpestmats <- matrix(NA, ngroups, nfact*(nfact+1L)/2)
         for(g in 1L:ngroups){
@@ -595,23 +591,24 @@ UpdateConstrain <- function(pars, constrain, invariance, nfact, nLambdas, J, ngr
         }
     }
     #remove redundent constraints
-    if(TRUE){
-        redun <- rep(FALSE, length(constrain))
-        if(length(constrain) > 0L){
-            for(i in 1L:length(redun)){
+    redun <- rep(FALSE, length(constrain))
+    if(length(constrain) > 0L){
+        for(i in 1L:length(redun)){
+            while(TRUE){
+                lastredun <- redun
                 for(j in 1L:length(redun)){
-                    if(j < i){
-                        if(all(constrain[[i]] %in% constrain[[j]]) ||
-                                all(constrain[[j]] %in% constrain[[i]])){
-                            if(length(constrain[[i]]) < length(constrain[[j]])) redun[i] <- TRUE
-                            else redun[j] <- TRUE
+                    if(i < j && !redun[j] && !redun[i]){
+                        if(any(constrain[[i]] %in% constrain[[j]])){
+                            constrain[[i]] <- unique(c(constrain[[i]], constrain[[j]]))
+                            redun[j] <- TRUE
                         }
                     }
                 }
+                if(all(lastredun == redun)) break
             }
         }
-        constrain[redun] <- NULL
     }
+    constrain[redun] <- NULL
     return(constrain)
 }
 
@@ -934,7 +931,7 @@ ItemInfo <- function(x, Theta, cosangle, total.info = TRUE){
         dx$grad[[i]] <- matrix(rowSums(dx$grad[[i]] * cosanglefull))
     for(i in 1L:x@ncat)
         info[,i] <- (dx$grad[[i]])^2 / P[ ,i]
-    if(total.info) info <- matrix(rowSums(info))
+    if(total.info) info <- rowSums(info)
     return(info)
 }
 
@@ -1045,7 +1042,7 @@ makeopts <- function(method = 'MHRM', draws = 2000L, calcLL = TRUE, quadpts = NU
                      SE = FALSE, verbose = TRUE, GenRandomPars,
                      SEtol = .001, grsm.block = NULL, D = 1, TOL = NULL,
                      rsm.block = NULL, calcNull = TRUE, BFACTOR = FALSE,
-                     technical = list(), use = 'pairwise.complete.obs',
+                     technical = list(),
                      SE.type = 'crossprod', large = NULL, accelerate = 'Ramsay', empiricalhist = FALSE,
                      optimizer = NULL, solnp_args = list(), alabama_args = list(), ...)
 {
@@ -1053,14 +1050,13 @@ makeopts <- function(method = 'MHRM', draws = 2000L, calcLL = TRUE, quadpts = NU
     tnames <- names(technical)
     gnames <- c('MAXQUAD', 'NCYCLES', 'BURNIN', 'SEMCYCLES', 'set.seed', 'SEtol', 'symmetric_SEM',
                 'gain', 'warn', 'message', 'customK', 'customPriorFun', 'customTheta', 'MHcand',
-                'parallel', 'NULL.MODEL', 'theta_lim', 'RANDSTART', 'MHDRAWS')
+                'parallel', 'NULL.MODEL', 'theta_lim', 'RANDSTART', 'MHDRAWS', 'removeEmptyRows')
     if(!all(tnames %in% gnames))
         stop('The following inputs to technical are invalid: ',
              paste0(tnames[!(tnames %in% gnames)], ' '), call.=FALSE)
     if(method == 'MHRM' || method == 'MIXED') SE.type <- 'MHRM'
     if(!(method %in% c('MHRM', 'MIXED', 'BL', 'EM', 'QMCEM')))
         stop('method argument not supported', call.=FALSE)
-    D <- 1
     opts$method = method
     if(draws < 1) stop('draws must be greater than 0', call.=FALSE)
     opts$draws = draws
@@ -1072,7 +1068,6 @@ makeopts <- function(method = 'MHRM', draws = 2000L, calcLL = TRUE, quadpts = NU
     opts$verbose = verbose
     opts$SEtol = ifelse(is.null(technical$SEtol), .001, technical$SEtol)
     opts$grsm.block = grsm.block
-    opts$D = D
     opts$rsm.block = rsm.block
     opts$calcNull = calcNull
     opts$customPriorFun = technical$customPriorFun
@@ -1086,10 +1081,11 @@ makeopts <- function(method = 'MHRM', draws = 2000L, calcLL = TRUE, quadpts = NU
         if(is.null(technical$NCYCLES)) technical$NCYCLES <- 1000L
     }
     if(is.null(technical$symmetric_SEM)) technical$symmetric_SEM <- TRUE
+    opts$removeEmptyRows <- if(is.null(technical$removeEmptyRows)) FALSE
+        else technical$removeEmptyRows
     opts$warn <- if(is.null(technical$warn)) TRUE else technical$warn
     opts$message <- if(is.null(technical$message)) TRUE else technical$message
     opts$technical <- technical
-    opts$use <- use
     opts$technical$parallel <- ifelse(is.null(technical$parallel), TRUE, technical$parallel)
     opts$MAXQUAD <- ifelse(is.null(technical$MAXQUAD), 20000L, technical$MAXQUAD)
     opts$NCYCLES <- ifelse(is.null(technical$NCYCLES), 2000L, technical$NCYCLES)
@@ -1405,27 +1401,6 @@ RMSEA.CI <- function(X2, df, N, ci.lower=.05, ci.upper=.95) {
     return(c(RMSEA.lower, RMSEA.upper))
 }
 
-assignInformationMG <- function(object){
-    J <- ncol(object@Data$data)
-    names <- colnames(object@information)
-    spl_names <- strsplit(names, split="\\.")
-    spl_names_par <- sapply(spl_names, function(x) x[1L])
-    spl_names <- lapply(spl_names,
-                        function(x) as.numeric(x[-1L]))
-    spl_names <- do.call(rbind, spl_names)
-    for(g in 1L:length(object@pars)){
-        from <- object@pars[[g]]@pars[[1L]]@parnum[1L]
-        to <- object@pars[[g]]@pars[[J+1L]]@parnum[length(
-            object@pars[[g]]@pars[[J+1L]]@parnum)]
-        pick <- spl_names[,g] >= from & spl_names[,g] <= to
-        tmp <- object@information[pick,pick]
-        colnames(tmp) <- rownames(tmp) <-
-            paste(spl_names_par[pick], spl_names[pick,g], sep='.')
-        object@pars[[g]]@information <- tmp
-    }
-    object
-}
-
 BL.LL <- function(p, est, longpars, pars, ngroups, J, Theta, PrepList, specific, sitems,
                CUSTOM.IND, EH, EHPrior, Data, BFACTOR, itemloc, theta){
     longpars[est] <- p
@@ -1672,16 +1647,17 @@ collapseCells <- function(O, E, mincell = 1){
 }
 
 MGC2SC <- function(x, which){
-    tmp <- x@pars[[which]]
+    tmp <- x@ParObjects$pars[[which]]
     ind <- 1L
-    for(i in 1L:length(tmp@pars)){
-        tmp@pars[[i]]@parnum[] <- seq(ind, ind + length(tmp@pars[[i]]@parnum) - 1L)
-        ind <- ind + length(tmp@pars[[i]]@parnum)
+    for(i in 1L:x@Data$nitems){
+        tmp@ParObjects$pars[[i]]@parnum[] <- seq(ind, ind + length(tmp@ParObjects$pars[[i]]@parnum) - 1L)
+        ind <- ind + length(tmp@ParObjects$pars[[i]]@parnum)
     }
     tmp@Data <- x@Data
     tmp@Data$data <- tmp@Data$data[tmp@Data$group == tmp@Data$groupName[which], , drop=FALSE]
     tmp@Data$Freq[[1L]] <- tmp@Data$Freq[[which]]
     tmp@Data$fulldata[[1L]] <- x@Data$fulldata[[which]]
+    ## TODO, add acov information in for subset
     tmp
 }
 
