@@ -53,14 +53,12 @@
 #' }
 wald <- function(object, L, C = 0){
     if(missing(object)) missingMsg('object')
-    if(all(dim(object@information) == c(1,1)))
-        if(object@information[1,1] == 0L)
+    if(all(dim(object@vcov) == c(1,1)))
+        if(object@vcov[1,1] == 0L)
             stop('No information matrix has been calculated for the model', call.=FALSE)
-    info <- object@information
-    keep <- !is.na(diag(info))
-    info <- info[keep, keep, drop=FALSE]
-    Names <- colnames(info)
-    B <- object@shortpars[keep]
+    covB <- object@vcov
+    Names <- colnames(covB)
+    B <- object@Internals$shortpars
     if(missing(L)){
         index <- 1L:length(Names)
         ret <- as.data.frame(t(data.frame(infoname=Names, par = round(B, 3))))
@@ -79,10 +77,6 @@ wald <- function(object, L, C = 0){
     } else if(length(C) != ncol(L)){
         stop('length(C) must be the same as ncol(L)', call.=FALSE)
     }
-    covB <- try(solve(info), silent=TRUE)
-    if(is(covB, 'try-error'))
-        stop('Could not properly invert information matrix to obtain parameter covariance matrix',
-             call.=FALSE)
     W <- t(L %*% (B - C)) %*% solve(L %*% covB %*% t(L)) %*% (L %*% (B - C))
     W <- ifelse(W < 0, 0, W)
     ret <- list(W=W, df = nrow(L))
